/**************************************************************************************************
	Developed by: the Colorado Health Institute (CHI)
	Contact Information: 
		Glenn Goodrich
		303-831-4200 x225
		goodrichg@coloradohealthinstitute.org

	The 2008 rural dentist public use file (PUF) was created with a 64-bit  
	version of SAS 9.2 on a 64-bit MS Windows operating system. If this data file will be 
	used with a 32-bit version of SAS 9.2 or earlier, the data file needs to be reassigned, 
	through a DATA STEP, so that it can subsequently assign the SAS formats correctly.

	The following code will execute the necessary DATA STEP described above and then assign 
	the SAS formats to the variables included in the dentist file. 

	INPUT: rden08_puf.sas7bdat (64-bit SAS 9.2 data file from CHI)
	OUTPUT: a data file compatible with the user's version of SAS, with its associated SAS formats 

	NOTATION:
		>> USER INPUT <<;
		indicates all places in the beginning of the code where the user 
		should input information.
	
***************************************************************************************************/
options mprint mlogic symbolgen;
%global filename lib fmtlib;

************************** USER INPUT REQUIRED FOR THIS SECTION ONLY *******************************;

*>> USER INPUT <<;
* INSTRUCTIONS: provide a name for the SAS library associated with the location of the final 
* version of the data file
* (Example: lib = Survey);
%let lib = ;

*>> USER INPUT <<;
* INSTRUCTIONS: directory pathname for where the final version of the data file will be stored
* (Example: "C:\MyData");
libname &lib. "";

*>> USER INPUT <<;
* INSTRUCTIONS: name for FINAL version of the data file (it must have a different filename 
* than the CHI version if it will be stored in the SAME directory)
* (Example: filename = SurveyData);
%let filename = ;


*>> USER INPUT <<;
* INSTRUCTIONS: directory path name for where the CHI version of the Research data file is located
* (Example: "C:\MyData\CHI");
libname LIB1 "";

*>> USER INPUT <<;
* INSTRUCTIONS: name for SAS library where the formats with be stored 
* (Example: fmtlib = rdfmt);
%let fmtlib = ;

*>> USER INPUT <<;
* INSTRUCTIONS: directory pathname for where format catalog will be stored
* (Example: "C:\MyData\Formats");
libname &fmtlib. "";

***************************************** END USER INPUT ******************************************
***************************************************************************************************;


options fmtsearch=(&fmtlib.);

* this DATA STEP will restructure the SAS data file to be compatible with user's version of SAS;
data &lib..&filename.; set lib1.rden08_puf; run;
proc format library=&fmtlib.;
value $rdst
'-9'		="Missing"
'-8'		=">Not Applicable<"
'AA'		="Armed Forces -Americas"
'AE'		="Armed Forces -Europe, Canada, Africa, Middle East"
'AK'		="Alaska"
'AL'		="Alabama"
'AP'		="Armed Forced -Pacific"
'AR'		="Arkansas"
'AS'		="American Samoa"
'AZ'		="Arizona"
'CA'		="California"
'CO'		="Colorado"
'CT'		="Connecticut"
'CM' 		="Northern Mariana Islands"
'MP'		="Northern Mariana Islands"
'DC'		="District of Columbia"
'DE'		="Delaware"
'FL'		="Florida"
'FM'		="Federated States of Micronesia"
'FO'		="Foreign Country"
'GA'		="Georgia"
'GU'		="Guam"
'HI'		="Hawaii"
'IA'		="Iowa"
'ID'		="Idaho"
'IL'		="Illinois"
'IN'		="Indiana"
'KS'		="Kansas"
'KY'		="Kentucky"
'LA'		="Louisiana"
'MA'		="Massachusetts"
'MD'		="Maryland"
'ME'		="Maine"
'MH'		="Marshall Islands"
'MI'		="Michigan"
'MN'		="Minnesota" 
'MO'		="Missouri"    
'MS'		="Mississippi"
'MT'		="Montana"
'NC'		="North Carolina"
'ND'		="North Dakota"
'NE'		="Nebraska"
'NH'		="New Hampshire"
'NJ'		="New Jersey"
'NM'		="New Mexico"
'NV'		="Nevada"
'NY'		="New York"
'OH'		="Ohio"
'OK'		="Oklahoma"
'OR'		="Oregon"
'PA'		="Pennsylvania"
'PR'		="Puerto Rico"
'PW'		="Palau"
'RI'		="Rhode Island"
'SC'		="South Carolina"
'SD'		="South Dakota"
'TN'		="Tennessee"
'TX'		="Texas"
'UT'		="Utah"
'VA'		="Virginia"
'VI'		="US Virgin Islands"
'VT'		="Vermont"
'WA'		="Washington"
'WI'		="Wisconsin"
'WV'		="West Virginia"
'WY'		="Wyoming"
'XX'		="Foreign Country"
other		=[$2.]
;
value agegprd
-9 = "Missing"
-8 = ">Not Applicable<"
1 = "34 years or younger"
2 = "35 - 44 years"
3 = "45 - 54 years"
4 = "55 - 64 years"
5 = "65 years or older"
;
value gend_rd
-9			='Missing'
-8			='>Not Applicable<'
1			='Male'
2			='Female'
;
value grdagerd
-9 = "Missing"
-8 = ">Not Applicable<"
1 = "25 years or younger"
2 = "26 - 30 years"
3 = "More than 30 years"
;
value grdgrprd
-9 = "Missing"
-8 = ">Not Applicable<"
1 = "0 - 5 years"
2 = "6 - 15 years"
3 = "16 - 25 years"
4 = "26 - 35 years"
5 = "More than 35"
;
value prost_rd_gp
-9 		="Missing"
-8 		=">Not Applicable<"
1		='Fulltime dentist actively seeing patients'
2		='Part-time dentist actively seeing patients'
3		='not seeing patients or other'
;
value r_s_u_rd
-9			="Missing"
-8			=">Not Applicable<"
1			="Rural"
2			="Suburban"
3			="Urban"
;
value rdcolvyr
-9			='Missing'
-8			='>Not Applicable<'
1			='1-10 years'
2			='11-25 years'
3			='26-35 years'
4			='More than 35 years'
;
value rddenhyg
-9			='Missing'
-8			='>Not Applicable<'
1			='0 hygienists'
2			='1 hygienist'
3			='More than 1 hygienist'
;
value rdftchr
-9			='Missing'
-8			='>Not Applicable<'
1			='None or one assistant'
2			='2 or 3 assistants'
3			='more than 3 assistants'
;
value rdftdeno
-9			='Missing'
-8			='>Not Applicable<'
1			='0 dentists'
2			='1 or more dentists'
;
value rdgradyr
-9			='Missing'
-8			='>Not Applicable<'
1			='1972 or before'
2			='1973-1982'
3			='1983-1992'
4			='1993-2002'
5			='2003-2008'
;
value rdgrstco
-9			='Missing'
-8			='>Not Applicable<'
0			='Non-Colorado'
1			='Colorado'
;
value rdimpnot
-9 		="Missing"
-8 		=">Not Applicable<"
0		="Not important or indifferent (3,4,5)"
1		="Important (1,2)"
2		="N/A"
;
value rdinad
-9			='Missing'
-8			='>Not Applicable<'
0			='Adequate or indifferent (1,2,3)'
1			='Inadequate (4,5)'
2			='N/A'
;
value rdlicyr
-9			='Missing'
-8			='>Not Applicable<'
1			='1984 or before'
2			='After 1984'
;
value rdlsvcpm
-9			='Missing'
-8			='>Not Applicable<'
1			='1-5 years'
2			='6-15 years'
3			='16-25 years'
4			='More than 25 years'
;
value rdprep
-9			='Missing'
-8			='>Not Applicable<'
0			='Prepared or indifferent (1,2,3)'
1			='Not prepared (4,5)'
;
value rdpryrco
-9			='Missing'
-8			='>Not Applicable<'
1			='1-10 years'
2			='11-25 years'
3			='More than 25 years'
;
value rdptchr
-9			='Missing'
-8			='>Not Applicable<'
1			='No assistants'
2			='1 assistant'
3			='More than 1 assistant'
;
value rdracepu
-9			='Missing'
-8			='>Not Applicable<'
0			='Non-white'
1			='White'
;
value rdrucgp
-9='Missing'
-8='>Not Applicable<'
1='Isolated'
2='Rural Small'
3='Rural Large'
;
value rdtmadlt
-9 		="Missing"
-8 		=">Not Applicable<"
1		="0-30 percent"
2		="31-40 percent"
3		="41-50 percent"
4		="51-60 percent"
5		="61-70 percent"
6		="More than 70 percent"
;
value rdtmchil
-9 		="Missing"
-8 		=">Not Applicable<"
1		="0-5 percent"
2		="6-10 percent"
3		="More than 10 percent"
;
value rdtminf
-9 		="Missing"
-8 		=">Not Applicable<"
1		='None or 0 percent'
2		='1 percent'
3		='More than 1 percent'
;
value rdtmoldadlt
-9 		="Missing"
-8 		=">Not Applicable<"
1		="0-5 percent"
2		="6-10 percent"
3		="11-20 percent"
4		="21-30 percent"
5		="More than 30 percent"
;
value rdtmteen
-9 		="Missing"
-8 		=">Not Applicable<"
1		="0-5 percent"
2		="6-10 percent"
3		="11-20 percent"
4		="More than 20 percent"
;
value rdtoprof
-9			='Missing'
-8			='>Not Applicable<'
1			='0-24 hours'
2			='25-32 hours'
3			='More than 32 hours'
;
value rdtotdir
-9			='Missing'
-8			='>Not Applicable<'
1			='0-24 hours'
2			='25-32 hours'
3			='More than 32 hours'
;
value rdvis
-9			='Missing'
-8			='>Not Applicable<'
1			='0-1000 visits'
2			='1001-2000 visits'
3			='2001-3000 visits'
4			='More than 3000 visits'
;
value rdyrbth
-9			='Missing'
-8			='>Not Applicable<'
1			='1943 or before'
2			='1944 to 1953'
3			='1954 to 1963'
4			='1964 to 1973'
5			='After 1973'
;
value stratnrd
-9="Missing"
-8=">Not Applicable<"
other=[8.4]
;
value urban_rd
-9 		="Missing"
-8 		=">Not Applicable<"
0		="Rural"
1		="Urban"
;
value y_n_rd
-9			="Missing"
-8			=">Not Applicable<"
0			="No"
1			="Yes"
;
value y_nnoprd
-9			="Missing"
-8			=">Not Applicable<"
0			="No"
1			="Yes"
2           ="No opinion"
;
value yn_na_rd
-9			="Missing"
-8			=">Not Applicable<"
0			="No"
1			="Yes"
2           ="N/A - Response"
;
run;
proc datasets library = &lib.;
	modify &filename.;
	format primary_state_from_zip $RDST.;
	format age_grp AGEGPRD.;
	format gender GEND_RD.;
	format grad_age_grp GRDAGERD.;
	format grad_numyrs_grp GRDGRPRD.;
	format employ_status_grp PROST_RD_GP.;
	format grewup_location R_S_U_RD.;
	format co_liveyrs_grp RDCOLVYR.;
	format FT_DENHYG_grp PT_DENHYG_grp RDDENHYG.;
	format FT_DENCHR_ASST_grp RDFTCHR.;
	format FT_DENT_OFFICE_grp PT_DENT_OFFICE_grp RDFTDENO.;
	format grad_year_grp RDGRADYR.;
	format grad_state_grp RDGRSTCO.;
	format REJECTMDCD_REIMBLOW_grp RDIMPNOT.;
	format REJECTMDCD_TIMECONS_grp RDIMPNOT.;
	format EDCARE_PREGNANT_grp EDCARE_INFANT_grp EDCARE_DISAB_grp EDCARE_BEHAVE_grp EDCARE_SETUP_PR_grp 
	EDCARE_MGMT_grp EDCARE_WORKWITH_grp EDCARE_ORTHO_grp EDCARE_PERIO_grp CLIN_PREGNANT_grp 
	CLIN_INFANT_grp CLIN_DISAB_grp CLIN_BEHAVE_grp CLIN_SETUP_PR_grp CLIN_MGMT_grp 
	CLIN_WORKWITH_grp CLIN_ORTHO_grp CLIN_PERIO_grp RDINAD.;
	format LICYR_CO_grp RDLICYR.;
	format LGTH_SVC_YR_PRIMARY_grp RDLSVCPM.;
	format PREPARE_MGMT_DENT_grp RDPREP.;
	format PRACYR_CO_grp RDPRYRCO.;
	format PT_DENCHR_ASST_grp RDPTCHR.;
	format race_grp RDRACEPU.;
	format RUCA_Class_from_zip RDRUCGP.;
	format PCTCARE_ADULT_grp RDTMADLT.;
	format PCTCARE_CHILDREN_grp RDTMCHIL.;
	format PCTCARE_INFANT_grp RDTMINF.;
	format PCTCARE_OLDADULT_grp RDTMOLDADLT.;
	format PCTCARE_TEEN_grp RDTMTEEN.;
	format HRS08_TOTPROF_grp RDTOPROF.;
	format HRS08_DIRCARE_grp RDTOTDIR.;
	format VISITS_2007_grp RDVIS.;
	format birth_yr_grp RDYRBTH.;
	format strata_wt STRATNRD.;
	format primary_urban_from_zip URBAN_RD.;
	format DEGR_DMD DEGR_OTH RECRUIT_DH LANG_OTHENG COLLAB_OTHERS SUPPORT_ROLEDH Y_N_RD.;
	format COMM_BENEFIT Y_NNOPRD.;
	format ada_spec COMM_SLOWPACE COMM_PER_FAM_REASONS COMM_RECREATION
	COMM_GOODSCHOOL COMM_SMALLPRC COMM_TOOKOVER COMM_OPP COMM_GREWUP_RURAL
	SERVE_SFS_INC ACCEPT_MDCAID ACCEPT_NEW_MDCAID ACCEPT_CHPP_PAY ACCEPT_NEW_CHPP_PAY YN_NA_RD.;
quit;
